#! /bin/sh

# propbasic2spin.sh shell command to run PropBasic-bst-osx from SimpleIDE on Mac OS X
# This version uses the open source spin compiler and NOT bstc for Mac OS X
#
# Example:
# propbasic2spin.sh -I /path_to_libs/ example.pbas
# 
# Will execute PropBasic-bst-osx against the .pbas file, creating a .spin source file
# That .spin file will be compiled by /opt/parallax/bin/spin to a .binary file
#
# Note: Since PropBasic does not use Spin libs, the -I parameter will be ignored
#

# get the last parameter, which should be the PropBasic .pbas file
next=$1
while [ -n "${next}" ] ; do
  pbas_file_path=$next
  shift
  next=$1
done

# parse the full path name for creation of a .spin filename
for fullpath in "$pbas_file_path"
do
    filename="${fullpath##*/}"                      # Strip longest match of */ from start
    dir="${fullpath:0:${#fullpath} - ${#filename}}" # Substring from 0 thru pos of filename
    base="${filename%.[^.]*}"                       # Strip shortest match of . plus at least one non-dot char from end
    ext="${filename:${#base} + 1}"                  # Substring from len of base thru end
    if [[ -z "$base" && -n "$ext" ]]; then          # If we have an extension and no base, it's really the base
        base=".$ext"
        ext=""
    fi
    #echo -e "$fullpath:\n\tdir  = \"$dir\"\n\tbase = \"$base\"\n\text  = \"$ext\""
done

# the .spin extension
spin_ext='.spin'

# compile the PropBasic file to a .spin file
echo Compiling $base.$ext to $dir$base$spin_ext
/opt/parallax/bin/PropBasic-bst.osx $fullpath /B

# Check for errors and setup to compile the .spin file
if [ "$?" = "0"  ]; then
    echo Successfully created $dir$base$spin_ext
    # compile the .spin file
    /opt/parallax/bin/spin $dir$base$spin_ext
else
    echo Error compiling $fullpath
    exit 1
fi
